@@ -74,10 +74,11 @@ def main():
         Input('upload_csv', 'filename'),
         Input('ts_annotation', 'selectedData'),
         Input('ts_annotation', 'clickData'),
+        Input('ts_annotation','relayoutData'),
         Input('save_file','n_clicks'),
         State('ts_annotation', 'figure'),
         State('filename','children'))
-    def process_callback(contents, filename, selected_data, click_data, save_file, fig, label):
+    def process_callback(contents, filename, selected_data, click_data, relayout_data, save_file, fig, label):
         global annotations
 
         # check which callback was triggered 
@@ -98,6 +99,10 @@ def main():
                     fig = create_timeseries_with_support_signal_and_annotations_plot(x,y,x,y_support,[],[])
                 else:
                     fig = create_timeseries_with_annotations_plot(x,y,[],[])
+                y = np.array(fig['data'][0]['y'])
+                y_min = np.min(y)
+                y_max = np.max(y)
+                fig['layout']['yaxis']['range'] = [y_min-0.05, y_max+0.05]
                 label = filename
                 return fig, label
             elif context == 'save_file':
@@ -136,6 +141,21 @@ def main():
                     if point_xy in annotations:
                         del annotations[annotations.index(point_xy)]
 
+        # handle figure range
+        if relayout_data:
+            try:
+                x_min = relayout_data['xaxis.range'][0]
+                x_max = relayout_data['xaxis.range'][1] 
+                x = np.array(fig['data'][0]['x'])
+                y = np.array(fig['data'][0]['y'])
+                idxs = np.where(np.logical_and(x>=x_min, x<=x_max))
+                y_min = np.min(y[idxs])
+                y_max = np.max(y[idxs])
+                fig['layout']['yaxis']['range'] = [y_min-0.05, y_max+0.05]
+            except KeyError:
+                print('key not found')
+                
+
         # update figure
         if len(annotations) > 0:
             fig['data'][len(fig['data'])-1]['x'] = np.array(annotations)[:,0]
@@ -143,6 +163,7 @@ def main():
         elif len(annotations) == 0:
             fig['data'][len(fig['data'])-1]['x'] = []
             fig['data'][len(fig['data'])-1]['y'] = []
+        
             
 
         return fig, label
